-module(egeoip_acl_tests).
-include_lib("eunit/include/eunit.hrl").

test_ips() ->
    [{<<192,168,0>>, <<"192.168.0">>},
     {<<200,23,11>>, <<"200.23.11">>},
     {<<127,127,127>>, <<"127.127.127">>}].

test_lines() ->
    [<<"acl \"CT_AnHui\" {\n">>,
     <<"60.166.0.0/24;60.166.1.0/24;60.166.2.0/24;60.166.3.0/24;\n">>,
     <<"60.166.10.0/24;60.166.11.0/24;60.166.12.0/24;60.166.13.0/24;\n">>,
     <<"};\n">>,
     <<"acl \"CNC_AnHui\" {\n">>,
     <<"58.243.45.0/24;58.242.46.0/24;58.242.47.0/24;58.242.48.0/24;\n">>,
     <<"};\n">>].

ip_parse_test_() ->
    [?_assertEqual(IP, egeoip_acl:parse_ip24(BinIP))
     || {IP, BinIP} <- test_ips()].

ips_parse_test() ->
    ?assertEqual(
       [<<60, 169, 4, 4>>,
        <<60, 166, 7, 7>>,
        <<60, 166, 3, 3>>,
        <<60, 166, 0, 0>>
       ],
       egeoip_acl:parse_ips(
         <<"60.166.0.0/24;60.166.7.0/24;\n60.166.3.0/24;60.169.4.0/24;">>)).

line_parse_test() ->
    ?assertEqual(
       [{<<"CNC_AnHui">>,
         [<<58, 243, 45, 45>>,
          <<58, 242, 46, 48>>]},
        {<<"CT_AnHui">>,
         [<<60, 166, 10, 13>>,
          <<60, 166, 0, 3>>]}],
       egeoip_acl:parse_line(test_lines(), [])).

